Mailer
------

Configuration
~~~~~~~~~~~~~

.. code-block:: yaml

    ioc.extra.mailer:
        host: localhost
        port:
        use_tls: false
        user:
        password:
        use_ssl: false

.. _Mailer: https://pypi.python.org/pypi/mailer